Inline gigabytes of data into a binary or library crate by emitting a static placed in .lrodata.* so the linker can use large-code-model relocations on 64-bit ELF targets.
static
.lrodata.*
blob!(<vis> static NAME, <path-expr>);